@@ -8,19 +8,25 @@ use Log::Log4perl qw( get_logger );
 use Workflow::Exception qw( persist_error );
 use English qw( -no_match_vars );
 
-$Workflow::Persister::DBI::SequenceId::VERSION = '1.52';
+$Workflow::Persister::DBI::SequenceId::VERSION = '1.53';
 
-my @FIELDS = qw( sequence_name sequence_select );
+my @FIELDS = qw( log sequence_name sequence_select );
 __PACKAGE__->mk_accessors(@FIELDS);
 
-my ($log);
+
+sub new {
+    my ( $class, $params ) = @_;
+    $params ||= {};
+    $params->{log} = get_logger( $class );
+
+    return bless { %$params }, $class;
+}
 
 sub pre_fetch_id {
     my ( $self, $dbh ) = @_;
-    $log ||= get_logger();
     my $full_select = sprintf $self->sequence_select, $self->sequence_name;
-    $log->is_debug
-        && $log->debug("SQL to fetch sequence: $full_select");
+    $self->log->is_debug
+        && $self->log->debug("SQL to fetch sequence: $full_select");
     my ($row);
     eval {
         my $sth = $dbh->prepare($full_select);
@@ -48,7 +54,7 @@ Workflow::Persister::DBI::SequenceId - Persister to fetch ID from a sequence
 
 =head1 VERSION
 
-This documentation describes version 1.52 of this package
+This documentation describes version 1.53 of this package
 
 =head1 SYNOPSIS
 
@@ -62,8 +68,36 @@ This documentation describes version 1.52 of this package
 
 Implementation for DBI persister to fetch an ID value from a sequence.
 
+=head2 Properties
+
+B<sequence_name>
+
+Name of the sequence to select the next id value from.
+
+B<sequence_select>
+
+C<sprintf> template string with a single placeholder (C<%s>) used to
+interpolate the sequence name. The resulting string is used as the SQL
+statement to retrieve the next sequence value.
+
+=head2 ATTRIBUTES
+
+=head3 log
+
+Contains the logger object associated with this instance.
+
 =head2 METHODS
 
+=head3 new ( \%params )
+
+This method instantiates a class for retrieval of sequence ids from a
+L<DBI> based persistance entity.
+
+It takes a hashref containing keys matching the properties outlines in the
+section above or throws L<Workflow::Exception>s if these are not defined.
+
+Returns instantiated object upon success.
+
 =head3 pre_fetch_id
 
 Returns a unique sequence id from a database.
