@@ -11,7 +11,7 @@ use Workflow::Persister::RandomId;
 use File::Slurp qw(slurp);
 use English qw( -no_match_vars );
 
-$Workflow::Persister::File::VERSION = '1.52';
+$Workflow::Persister::File::VERSION = '1.53';
 
 my @FIELDS = qw( path );
 __PACKAGE__->mk_accessors(@FIELDS);
@@ -19,7 +19,6 @@ __PACKAGE__->mk_accessors(@FIELDS);
 sub init {
     my ( $self, $params ) = @_;
     $self->SUPER::init($params);
-    my $log = get_logger();
     unless ( $self->use_uuid eq 'yes' || $self->use_random eq 'yes' ) {
         $self->use_random('yes');
     }
@@ -33,20 +32,19 @@ sub init {
             "specified in the 'path' key of the configuration ",
             "(given: '$params->{path}')";
     }
-    $log->is_info
-        && $log->info(
+    $self->log->is_info
+        && $self->log->info(
         "Using path for workflows and histories '$params->{path}'");
     $self->path( $params->{path} );
 }
 
 sub create_workflow {
     my ( $self, $wf ) = @_;
-    my $log       = get_logger();
     my $generator = $self->workflow_id_generator;
     my $wf_id     = $generator->pre_fetch_id();
     $wf->id($wf_id);
-    $log->is_debug
-        && $log->debug("Generated workflow ID '$wf_id'");
+    $self->log->is_debug
+        && $self->log->debug("Generated workflow ID '$wf_id'");
     $self->_serialize_workflow($wf);
     my $full_history_path = $self->_get_history_path($wf);
     mkdir( $full_history_path, 0777 )
@@ -57,16 +55,15 @@ sub create_workflow {
 
 sub fetch_workflow {
     my ( $self, $wf_id ) = @_;
-    my $log       = get_logger();
     my $full_path = $self->_get_workflow_path($wf_id);
-    $log->is_debug
-        && $log->debug("Checking to see if workflow exists in '$full_path'");
+    $self->log->is_debug
+        && $self->log->debug("Checking to see if workflow exists in '$full_path'");
     unless ( -f $full_path ) {
-        $log->error("No file at path '$full_path'");
+        $self->log->error("No file at path '$full_path'");
         persist_error "No workflow with ID '$wf_id' is available";
     }
-    $log->is_debug
-        && $log->debug("File exists, reconstituting workflow");
+    $self->log->is_debug
+        && $self->log->debug("File exists, reconstituting workflow");
     my $wf_info = eval { $self->constitute_object($full_path) };
     if ($EVAL_ERROR) {
         persist_error "Cannot reconstitute data from file for ",
@@ -83,34 +80,32 @@ sub update_workflow {
 sub create_history {
     my ( $self, $wf, @history ) = @_;
     my $generator   = $self->history_id_generator;
-    my $log         = get_logger();
     my $history_dir = $self->_get_history_path($wf);
-    $log->is_info
-        && $log->info("Will use directory '$history_dir' for history");
+    $self->log->is_info
+        && $self->log->info("Will use directory '$history_dir' for history");
     foreach my $history (@history) {
         if ( $history->is_saved ) {
-            $log->is_debug
-                && $log->debug("History object saved, skipping...");
+            $self->log->is_debug
+                && $self->log->debug("History object saved, skipping...");
             next;
         }
-        $log->is_debug
-            && $log->debug("History object unsaved, continuing...");
+        $self->log->is_debug
+            && $self->log->debug("History object unsaved, continuing...");
         my $history_id = $generator->pre_fetch_id();
         $history->id($history_id);
         my $history_file = catfile( $history_dir, $history_id );
         $self->serialize_object( $history_file, $history );
-        $log->is_info
-            && $log->info("Created history object '$history_id' ok");
+        $self->log->is_info
+            && $self->log->info("Created history object '$history_id' ok");
         $history->set_saved();
     }
 }
 
 sub fetch_history {
     my ( $self, $wf ) = @_;
-    my $log         = get_logger();
     my $history_dir = $self->_get_history_path($wf);
-    $log->is_debug
-        && $log->debug(
+    $self->log->is_debug
+        && $self->log->debug(
         "Trying to read history files from dir '$history_dir'");
     opendir( HISTORY, $history_dir )
         || persist_error "Cannot read history from '$history_dir': $!";
@@ -120,8 +115,8 @@ sub fetch_history {
     my @histories = ();
 
     foreach my $history_file (@history_files) {
-        $log->is_debug
-            && $log->debug("Reading history from file '$history_file'");
+        $self->log->is_debug
+            && $self->log->debug("Reading history from file '$history_file'");
         my $history = $self->constitute_object($history_file);
         $history->set_saved();
         push @histories, $history;
@@ -131,11 +126,10 @@ sub fetch_history {
 
 sub _serialize_workflow {
     my ( $self, $wf ) = @_;
-    my $log = get_logger();
     local $Data::Dumper::Indent = 1;
     my $full_path = $self->_get_workflow_path( $wf->id );
-    $log->is_debug
-        && $log->debug("Trying to write workflow to '$full_path'");
+    $self->log->is_debug
+        && $self->log->debug("Trying to write workflow to '$full_path'");
     my %wf_info = (
         id          => $wf->id,
         state       => $wf->state,
@@ -145,23 +139,22 @@ sub _serialize_workflow {
 
     );
     $self->serialize_object( $full_path, \%wf_info );
-    $log->is_debug
-        && $log->debug("Wrote workflow ok");
+    $self->log->is_debug
+        && $self->log->debug("Wrote workflow ok");
 }
 
 sub serialize_object {
     my ( $self, $path, $object ) = @_;
-    my $log = get_logger();
-    $log->is_info
-        && $log->info( "Trying to save object of type '",
+    $self->log->is_info
+        && $self->log->info( "Trying to save object of type '",
         ref($object), "' ", "to path '$path'" );
     open( THINGY, '>', $path )
         || persist_error "Cannot write to '$path': $!";
     print THINGY Dumper($object)
         || persist_error "Error writing to '$path': $!";
     close(THINGY) || persist_error "Cannot close '$path': $!";
-    $log->is_debug
-        && $log->debug("Wrote object to file ok");
+    $self->log->is_debug
+        && $self->log->debug("Wrote object to file ok");
 }
 
 sub constitute_object {
@@ -178,9 +171,8 @@ sub constitute_object {
 
 sub _get_workflow_path {
     my ( $self, $wf_id ) = @_;
-    my $log = get_logger();
-    $log->is_info
-        && $log->info( "Creating workflow file from '",
+    $self->log->is_info
+        && $self->log->info( "Creating workflow file from '",
         $self->path, "' ", "and ID '$wf_id'" );
     return catfile( $self->path, $wf_id . '_workflow' );
 }
@@ -202,7 +194,7 @@ Workflow::Persister::File - Persist workflow and history to the filesystem
 
 =head1 VERSION
 
-This documentation describes version 1.52 of this package
+This documentation describes version 1.53 of this package
 
 =head1 SYNOPSIS
 
